Flow Routing
============

.. currentmodule:: fastscapelib

Flow graph
----------

.. autosummary::
   :toctree: _api_generated/
   :template: fastscapelib-class-template.rst

   FlowGraph
   FlowGraphImpl

.. _py-api-flow-operators:

Flow operators
--------------

.. autosummary::
   :toctree: _api_generated/

   FlowDirection
   FlowOperator

Flow routers
~~~~~~~~~~~~

.. autosummary::
   :toctree: _api_generated/
   :template: fastscapelib-class-template.rst

   SingleFlowRouter
   MultiFlowRouter

Sink resolvers
~~~~~~~~~~~~~~

.. autosummary::
   :toctree: _api_generated/
   :template: fastscapelib-class-template.rst

   PFloodSinkResolver
   MSTSinkResolver

Flow snapshots
~~~~~~~~~~~~~~

.. autosummary::
   :toctree: _api_generated/

   FlowSnapshot
